@@ -15,7 +15,7 @@ import mysql.connector
 import six
 from mysql.connector import errorcode
 from packaging import version
-from tqdm import trange
+from tqdm import tqdm, trange
 
 from sqlite3_to_mysql.sqlite_utils import (
     adapt_decimal,
@@ -32,6 +32,46 @@ if six.PY2:
 class SQLite3toMySQL:
     """Use this class to transfer an SQLite 3 database to MySQL."""
 
+    # shamelessly copied from SQLAlchemy's dialects/mysql/__init__.py
+    MYSQL_COLUMN_TYPES = {
+        "BIGINT",
+        "BINARY",
+        "BIT",
+        "BLOB",
+        "BOOLEAN",
+        "CHAR",
+        "DATE",
+        "DATETIME",
+        "DECIMAL",
+        "DOUBLE",
+        "ENUM",
+        "DECIMAL",
+        "FLOAT",
+        "INTEGER",
+        "INTEGER",
+        "JSON",
+        "LONGBLOB",
+        "LONGTEXT",
+        "MEDIUMBLOB",
+        "MEDIUMINT",
+        "MEDIUMTEXT",
+        "NCHAR",
+        "NVARCHAR",
+        "NUMERIC",
+        "SET",
+        "SMALLINT",
+        "REAL",
+        "TEXT",
+        "TIME",
+        "TIMESTAMP",
+        "TINYBLOB",
+        "TINYINT",
+        "TINYTEXT",
+        "VARBINARY",
+        "VARCHAR",
+        "YEAR",
+    }
+
     COLUMN_PATTERN = re.compile(r"^[^(]+")
     COLUMN_LENGTH_PATTERN = re.compile(r"\(\d+\)$")
 
@@ -70,6 +110,8 @@ class SQLite3toMySQL:
 
         self._mysql_port = int(kwargs.get("mysql_port") or 3306)
 
+        self._mysql_ssl_disabled = kwargs.get("mysql_ssl_disabled") or False
+
         self._chunk_size = int(kwargs.get("chunk")) if kwargs.get("chunk") else None
 
         self._quiet = kwargs.get("quiet") or False
@@ -113,6 +155,7 @@ class SQLite3toMySQL:
                 password=self._mysql_password,
                 host=self._mysql_host,
                 port=self._mysql_port,
+                ssl_disabled=self._mysql_ssl_disabled,
                 use_pure=True,
             )
             if not self._mysql.is_connected():
@@ -283,6 +326,8 @@ class SQLite3toMySQL:
             return match.group(0).upper() + length
         if data_type in {"INT64", "NUMERIC"}:
             return "BIGINT" + self._column_type_length(column_type, 19)
+        if data_type not in self.MYSQL_COLUMN_TYPES:
+            return self._mysql_string_type
         return full_column_type
 
     @classmethod
@@ -521,7 +566,15 @@ class SQLite3toMySQL:
                 )
         else:
             self._mysql_cur.executemany(
-                sql, (tuple(row) for row in self._sqlite_cur.fetchall())
+                sql,
+                (
+                    tuple(row)
+                    for row in tqdm(
+                        self._sqlite_cur.fetchall(),
+                        total=total_records,
+                        disable=self._quiet,
+                    )
+                ),
             )
         self._mysql.commit()
 
